@@ -5,6 +5,7 @@ mod infrastructure;
 pub mod app {
     use super::application;
 
+    pub use application::command;
     pub use application::http::controller;
     pub use application::http::middleware;
     pub use application::http::router;
@@ -12,6 +13,7 @@ pub mod app {
     pub mod domain {
         use super::super::domain;
 
+        pub use domain::program_verification;
         pub use domain::project::manifest;
         pub use domain::value_object;
         pub use domain::verification_runtime;
@@ -21,10 +23,14 @@ pub mod app {
 pub mod infra {
     use super::infrastructure;
 
+    pub use infrastructure::display;
+    pub use infrastructure::program_verification;
     pub use infrastructure::scaffold;
     pub use infrastructure::service::*;
     pub use infrastructure::signal_handling;
+    pub use infrastructure::sigpipe;
     pub use infrastructure::verification_runtime;
+    pub use infrastructure::PROGRAM_VERIFICATION;
 }
 
 #[cfg(test)]
